[TOC]

Usage
=====
All searches object are placed here.

Objects
-------

### Search
It a super class for all searches via search line in MAL.

All the other inheritance from it and changes some consts.

 * SearchAccounts - find accounts.
 * SearchAnimes - find animes.
 * SearchMangas - find mangas.
